summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmbumpmapedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmbumpmapedit.h')
-rw-r--r--kpovmodeler/pmbumpmapedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmbumpmapedit.h b/kpovmodeler/pmbumpmapedit.h
index 109128d6..8404229b 100644
--- a/kpovmodeler/pmbumpmapedit.h
+++ b/kpovmodeler/pmbumpmapedit.h
@@ -45,12 +45,13 @@ class TQPushButton;
class PMBumpMapEdit : public PMDialogEditBase
{
Q_OBJECT
+ TQ_OBJECT
typedef PMDialogEditBase Base;
public:
/**
* Creates a PMBumpMapEdit with parent and name
*/
- PMBumpMapEdit( TQWidget* parent, const char* name = 0 );
+ PMBumpMapEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
/** */
@@ -45,12 +45,13 @@ class TQPushButton;
public:
/**
- * Creates a PMBumpMapEdit with parent and name
+ * Creates a PMBumpMapEdit with tqparent and name
*/